Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(697)

Unified Diff: third_party/WebKit/Source/web/tests/FrameTestHelpers.h

Issue 2917343004: Move LoadHTMLString method from WebFrame to WebLocalFrame. (Closed)
Patch Set: Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/web/tests/FrameTestHelpers.h
diff --git a/third_party/WebKit/Source/web/tests/FrameTestHelpers.h b/third_party/WebKit/Source/web/tests/FrameTestHelpers.h
index 8c752a52cf2463b0e5597e2713bd87f3384ff881..cf22912f0158255193c8e16200e3024dfd941435 100644
--- a/third_party/WebKit/Source/web/tests/FrameTestHelpers.h
+++ b/third_party/WebKit/Source/web/tests/FrameTestHelpers.h
@@ -68,8 +68,10 @@ class TestWebViewClient;
// pending resource requests, as well as waiting for the threaded parser to
// finish, before returning.
void LoadFrame(WebFrame*, const std::string& url);
-// Same as above, but for WebFrame::loadHTMLString().
-void LoadHTMLString(WebFrame*, const std::string& html, const WebURL& base_url);
+// Same as above, but for WebLocalFrame::LoadHTMLString().
+void LoadHTMLString(WebLocalFrame*,
+ const std::string& html,
+ const WebURL& base_url);
// Same as above, but for WebFrame::loadHistoryItem().
void LoadHistoryItem(WebFrame*,
const WebHistoryItem&,

Powered by Google App Engine
This is Rietveld 408576698